summaryrefslogtreecommitdiffstats
path: root/include/llvm/Support/SystemUtils.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Support/SystemUtils.h')
-rw-r--r--include/llvm/Support/SystemUtils.h18
1 files changed, 10 insertions, 8 deletions
diff --git a/include/llvm/Support/SystemUtils.h b/include/llvm/Support/SystemUtils.h
index 9a33fa3..b3d83fc 100644
--- a/include/llvm/Support/SystemUtils.h
+++ b/include/llvm/Support/SystemUtils.h
@@ -15,27 +15,29 @@
#ifndef LLVM_SUPPORT_SYSTEMUTILS_H
#define LLVM_SUPPORT_SYSTEMUTILS_H
-#include "llvm/System/Program.h"
+#include <string>
namespace llvm {
+ class raw_ostream;
+ namespace sys { class Path; }
-/// Determine if the ostream provided is connected to the std::cout and
+/// Determine if the raw_ostream provided is connected to the outs() and
/// displayed or not (to a console window). If so, generate a warning message
/// advising against display of bitcode and return true. Otherwise just return
/// false
/// @brief Check for output written to a console
bool CheckBitcodeOutputToConsole(
- std::ostream* stream_to_check, ///< The stream to be checked
- bool print_warning = true ///< Control whether warnings are printed
+ raw_ostream &stream_to_check, ///< The stream to be checked
+ bool print_warning = true ///< Control whether warnings are printed
);
/// FindExecutable - Find a named executable, giving the argv[0] of program
-/// being executed. This allows us to find another LLVM tool if it is built into
-/// the same directory, but that directory is neither the current directory, nor
-/// in the PATH. If the executable cannot be found, return an empty string.
+/// being executed. This allows us to find another LLVM tool if it is built in
+/// the same directory. If the executable cannot be found, return an
+/// empty string.
/// @brief Find a named executable.
sys::Path FindExecutable(const std::string &ExeName,
- const std::string &ProgramPath);
+ const char *Argv0, void *MainAddr);
} // End llvm namespace
OpenPOWER on IntegriCloud